@@ -1,6 +1,6 @@
 # China.pm
 # by Martin Thurn
-# $Id: China.pm,v 2.3 2004/05/13 21:26:23 Daddy Exp $
+# $Id: China.pm,v 2.4 2004/09/12 12:51:13 Daddy Exp $
 
 =head1 NAME
 
@@ -62,7 +62,7 @@ use strict;
 use vars qw( @ISA $VERSION $MAINTAINER );
 @ISA = qw( WWW::Search::Yahoo );
 
-$VERSION = do { my @r = (q$Revision: 2.3 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.4 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 sub native_setup_search
@@ -85,7 +85,7 @@ sub _string_has_count
   # THIS IS THE ENGLISH VERSION, I NEED A CHINESE READER TO SEND ME
   # THE CORRECT PATTERN.  UNTIL THEN THIS MODULE WILL ALWAYS RETURN
   # 0 in approximate_result_count.
-  return $1 if ($s =~ m!\bout\s+of\s+(?:about\s+)?([,0-9]+)!i);
+  return $1 if ($s =~ m!\bof\s+(?:about\s+)?([,0-9]+)!i);
   return -1;
   } # _string_has_count
 
